[![PyPI version](https://badge.fury.io/py/pysteg.svg)](https://badge.fury.io/py/pysteg)

# pysteg
pysteg is a python library for image steganography.

From Wikipedia:  
Steganography is the practice of concealing a message within another message or a physical object.  
In computing/electronic contexts, a computer file, message, image, or video is concealed within another file, message, image, or video.  
The word steganography comes from Greek steganographia, which combines the words steganós (στεγανός), meaning "covered or concealed", and -graphia (γραφή) meaning "writing".

# Usage
Please see usage_example.py

# Dependencies
cryptography and imageio  
Built with poetry

# License
MIT